@@ -645,6 +645,8 @@ def cli_parser():
     group3.add_argument('--control-build',  default=None,
         help='Override control build with artifacts located on this path. '
         'Allows reusing previous build as baseline.')
+    group3.add_argument('--append-build-command',  default=None, metavar='COMMANDS',
+        help='Append arguments to the build command')
 
     return parser
 
@@ -830,6 +832,9 @@ def run(argv, dry_run=None):
         logger.warning("diffoscope not available, falling back to regular diff")
         diffoscope_args = None
     control_build = parsed_args.control_build
+    append_build_command = parsed_args.append_build_command
+    if append_build_command :
+        build_command = ' '.join([build_command, append_build_command])
 
     if not artifact_pattern:
         print("No <artifact> to test for differences provided. See --help for options.")
